==> fusenshi-0.7.5.tgz: fusenshi-0.7.5/src/wnd/fusenshimainwndeventprocessor.h <==
/*
 * $Id: fusenshimainwndeventprocessor.h,v 1.6 2005/07/28 07:05:22 ozawa Exp $
 *
 * Copyright 2004- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.6 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___FUSENSHIMAINWNDEVENTPROCESSOR_H
#define ___FUSENSHIMAINWNDEVENTPROCESSOR_H

#include <gtkmm.h>

class FusenshiMainWndEventProcessor
{
public:
    /**
     * 󥹥ȥ饯
     */
    FusenshiMainWndEventProcessor();
    
    /**
     * ǥȥ饯
     */
    virtual ~FusenshiMainWndEventProcessor();

protected:
    /**
     * ޥܥ󲡲
     */
    virtual bool on_button_press_event(GdkEventButton* pEvent);
    
    /**
     * ݥåץåץ˥塼Ρֺ̤ɽפα
     */
    virtual void on_menu_raise_windows();

    /**
     * ݥåץåץ˥塼Ρɽɽפα
     */
    virtual void on_menu_hide_windows();
    
    /**
     * ݥåץåץ˥塼Ρֺפα
     */
    virtual void on_menu_refresh_windows();
    
    /**
     * ݥåץåץ˥塼Ρפα
     */
    virtual void on_menu_property_activate();
    
    /**
     * ݥåץåץ˥塼ΡĤפα
     */
    virtual void on_menu_close_activate();

private:
    /**
     * ݥåץåץ˥塼ۡޤ
     */
    bool buildPopupMenu();

    /**
     * ݥåץåץ˥塼ɽޤ
     */
    void showPopupMenu(GdkEventButton* pEvent);

private:
    /**
     * ݥåץåץ˥塼
     */
    Gtk::Menu m_cPopupMenu;

    /**
     * ݥåץåץ˥塼ιۥե饰
     */
    bool m_bPopupMenuBuildFlag;

    /**
     * activeʥΥåץե饰
     */
    bool m_bSkipActive;
};

#endif

==> fusenshi-0.8.2.tgz: fusenshi-0.8.2/src/wnd/fusenshimainwndeventprocessor.h <==
/*
 * $Id: fusenshimainwndeventprocessor.h,v 1.7 2006/02/02 10:13:07 ozawa Exp $
 *
 * Copyright 2004- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.7 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___FUSENSHIMAINWNDEVENTPROCESSOR_H
#define ___FUSENSHIMAINWNDEVENTPROCESSOR_H

#include "fusenshimenu.h"
#include "gtkmm.h"

class FusenshiMainWndEventProcessor
{
public:
    /**
     * 󥹥ȥ饯
     */
    FusenshiMainWndEventProcessor();
    
    /**
     * ǥȥ饯
     */
    virtual ~FusenshiMainWndEventProcessor();

protected:
    /**
     * ޥܥ󲡲
     */
    virtual bool on_button_press_event(GdkEventButton* pEvent);
    
    /**
     * ݥåץåץ˥塼Ρֺ̤ɽפα
     */
    virtual void on_menu_raise_windows();

    /**
     * ݥåץåץ˥塼Ρɽɽפα
     */
    virtual void on_menu_hide_windows();
    
    /**
     * ݥåץåץ˥塼Ρֺפα
     */
    virtual void on_menu_refresh_windows();
    
    /**
     * ݥåץåץ˥塼Ρפα
     */
    virtual void on_menu_property_activate();
    
    /**
     * ݥåץåץ˥塼ΡĤפα
     */
    virtual void on_menu_close_activate();

private:
    /**
     * ݥåץåץ˥塼ۡޤ
     */
    bool buildPopupMenu();

    /**
     * ݥåץåץ˥塼ɽޤ
     */
    void showPopupMenu(GdkEventButton* pEvent);

private:
    /**
     * ݥåץåץ˥塼
     */
    FusenshiMenu m_cPopupMenu;

    /**
     * ݥåץåץ˥塼ιۥե饰
     */
    bool m_bPopupMenuBuildFlag;

    /**
     * activeʥΥåץե饰
     */
    bool m_bSkipActive;
};

#endif
